This crate contains kube-rs compatible bindings for Kubernetes custom resources for the templates.gatekeeper.sh group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
templates.gatekeeper.sh/v1
ConstraintTemplate
templates.gatekeeper.sh/v1alpha1
ConstraintTemplate
templates.gatekeeper.sh/v1beta1
ConstraintTemplate